--- old/usr/src/cmd/Makefile	2016-02-16 06:50:33.607746443 -0500
+++ new/usr/src/cmd/Makefile	2016-02-16 06:50:33.613629542 -0500
@@ -25,6 +25,7 @@
 # Copyright (c) 2012 by Delphix. All rights reserved.
 # Copyright (c) 2013 DEY Storage Systems, Inc. All rights reserved.
 # Copyright 2014 Garrett D'Amore <garrett@damore.org>
+# Copyright 2014 Andrew Stormont.
 
 include ../Makefile.master
 
@@ -437,7 +438,6 @@
 	vgrind		\
 	vi		\
 	volcheck	\
-	volrmmount	\
 	vrrpadm		\
 	vscan		\
 	vt		\
@@ -716,7 +716,6 @@
 	vgrind		\
 	vi		\
 	volcheck	\
-	volrmmount	\
 	vrrpadm		\
 	vscan		\
 	w		\
--- old/usr/src/cmd/rmformat/Makefile	2016-02-16 06:50:33.792677403 -0500
+++ new/usr/src/cmd/rmformat/Makefile	2016-02-16 06:50:33.798595162 -0500
@@ -23,6 +23,8 @@
 # Copyright 2005 Sun Microsystems, Inc.  All rights reserved.
 # Use is subject to license terms.
 #
+# Copyright 2014 Andrew Stormont.
+#
 
 PROG= rmformat
 
@@ -34,8 +36,6 @@
 
 LDLIBS +=	-lsmedia -lvolmgt -ladm -lefi
 
-CERRWARN += -_gcc=-Wno-uninitialized
-
 LINTFLAGS += -u
 CPPFLAGS += -D_FILE_OFFSET_BITS=64
 
--- old/usr/src/cmd/rmformat/rmf_menu.c	2016-02-16 06:50:33.960071460 -0500
+++ new/usr/src/cmd/rmformat/rmf_menu.c	2016-02-16 06:50:33.966757833 -0500
@@ -17,10 +17,12 @@
  * information: Portions Copyright [yyyy] [name of copyright owner]
  *
  * CDDL HEADER END
- */
-/*
+ *
+ *
  * Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
+ *
+ * Copyright 2014 Andrew Stormont.
  */
 
 /*
@@ -308,7 +310,7 @@
 static void
 process_F_flag(smedia_handle_t handle, int32_t fd)
 {
-	uint32_t format_flag;
+	uint32_t format_flag = 0;
 	int32_t old_per = 0;
 	int32_t new_per, ret_val;
 
@@ -415,7 +417,7 @@
 	int removable;
 	int total_devices_found_last_time;
 	int defer = 0;
-	char *tmpstr;
+	char *tmpstr = NULL;
 
 #define	MAX_RETRIES_FOR_SCANNING 3
 
--- old/usr/src/cmd/rmformat/rmf_slice.c	2016-02-16 06:50:34.377838779 -0500
+++ new/usr/src/cmd/rmformat/rmf_slice.c	2016-02-16 06:50:34.383771146 -0500
@@ -17,10 +17,12 @@
  * information: Portions Copyright [yyyy] [name of copyright owner]
  *
  * CDDL HEADER END
- */
-/*
+ *
+ *
  * Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
+ *
+ * Copyright 2014 Andrew Stormont.
  */
 
 /*
@@ -883,7 +885,7 @@
 	diskaddr_t min_val;
 	int32_t min_slice, num_slices;
 	diskaddr_t media_size;
-	uint32_t cyl_size;
+	uint32_t cyl_size = 0;
 	int sparc_style = 0;	/* sparc_style handling ? */
 	struct fdisk_info fdisk;
 	int sol_part;
--- old/usr/src/cmd/rmvolmgr/vold.c	2016-02-16 06:50:34.585677295 -0500
+++ new/usr/src/cmd/rmvolmgr/vold.c	2016-02-16 06:50:34.591607850 -0500
@@ -17,10 +17,12 @@
  * information: Portions Copyright [yyyy] [name of copyright owner]
  *
  * CDDL HEADER END
- */
-/*
+ *
+ *
  * Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
+ *
+ * Copyright 2014 Andrew Stormont
  */
 
 /*
@@ -130,7 +132,6 @@
 #define	NOTIFY_DIR	"/tmp/.removable"	/* dir where filemgr looks */
 #define	NOTIFY_NAME	"notify"		/* named pipe to talk over */
 
-static void	volrmmount_usage();
 static void	volcheck_usage();
 static int	vold_action(struct action_arg *aap);
 static void	vold_update_mountpoints(struct action_arg *aap);
--- old/usr/src/cmd/rmvolmgr/vold.h	2016-02-16 06:50:34.775831987 -0500
+++ new/usr/src/cmd/rmvolmgr/vold.h	2016-02-16 06:50:34.781702274 -0500
@@ -17,17 +17,17 @@
  * information: Portions Copyright [yyyy] [name of copyright owner]
  *
  * CDDL HEADER END
- */
-/*
+ *
+ *
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
+ *
+ * Copyright 2014 Andrew Stormont.
  */
 
 #ifndef	_VOLD_H
 #define	_VOLD_H
 
-#pragma ident	"%Z%%M%	%I%	%E% SMI"
-
 #ifdef	__cplusplus
 extern "C" {
 #endif
@@ -63,7 +63,6 @@
 int vold_postprocess(LibHalContext *hal_ctx, const char *udi,
     struct action_arg *aap);
 int vold_rmmount(int argc, char **argv);
-int volrmmount(int argc, char **argv);
 int volcheck(int argc, char **argv);
 
 #ifdef	__cplusplus
--- old/usr/src/cmd/volrmmount/Makefile	2016-02-16 06:50:34.941257364 -0500
+++ /dev/null	2016-02-16 06:50:34.000000000 -0500
@@ -1,71 +0,0 @@
-#
-# CDDL HEADER START
-#
-# The contents of this file are subject to the terms of the
-# Common Development and Distribution License (the "License").
-# You may not use this file except in compliance with the License.
-#
-# You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
-# or http://www.opensolaris.org/os/licensing.
-# See the License for the specific language governing permissions
-# and limitations under the License.
-#
-# When distributing Covered Code, include this CDDL HEADER in each
-# file and include the License file at usr/src/OPENSOLARIS.LICENSE.
-# If applicable, add the following below this CDDL HEADER, with the
-# fields enclosed by brackets "[]" replaced with your own identifying
-# information: Portions Copyright [yyyy] [name of copyright owner]
-#
-# CDDL HEADER END
-#
-#
-# Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
-# Use is subject to license terms.
-#
-
-PROG =		volrmmount
-LOCAL_OBJS =	volrmmount.o
-RMVOLMGR_OBJS =	rmm_common.o vold.o
-OBJS =		$(LOCAL_OBJS) $(RMVOLMGR_OBJS)
-LOCAL_SRCS =	$(LOCAL_OBJS:%.o=%.c)
-RMVOLGMR_SRCS =	$(RMVOLMGR_OBJS:%.o=$(SRC)/cmd/rmvolmgr/%.c)
-SRCS =		$(LOCAL_SRCS) $(RMVOLMGR_SRCS)
-
-include $(SRC)/cmd/Makefile.cmd
-include $(SRC)/cmd/hal/Makefile.hal
-
-LDLIBS +=	-ldbus-1 -ldbus-glib-1 -lglib-2.0 -lhal -lhal-storage -lcontract
-
-CPPFLAGS +=	$(HAL_DBUS_CPPFLAGS) $(HAL_GLIB_CPPFLAGS)
-CPPFLAGS +=	-I$(ROOT)/usr/include/hal
-CPPFLAGS +=	-I$(SRC)/cmd/rmvolmgr
-C99MODE =	$(C99_ENABLE)
-
-CERRWARN +=	-_gcc=-Wno-switch
-CERRWARN +=	-_gcc=-Wno-unused-variable
-CERRWARN +=	-_gcc=-Wno-parentheses
-CERRWARN +=	-_gcc=-Wno-uninitialized
-CERRWARN +=	-_gcc=-Wno-unused-function
-
-.KEEP_STATE:
-
-all: $(PROG)
-
-$(PROG): $(OBJS)
-	$(LINK.c) -o $(PROG) $(OBJS) $(LDLIBS)
-	$(POST_PROCESS)
-
-install: all $(ROOTPROG)
-
-rmm_common.o: $(SRC)/cmd/rmvolmgr/rmm_common.c $(SRC)/cmd/rmvolmgr/rmm_common.h
-	$(COMPILE.c) -o $@ $(SRC)/cmd/rmvolmgr/rmm_common.c
-	$(POST_PROCESS_O)
-
-vold.o: $(SRC)/cmd/rmvolmgr/vold.c $(SRC)/cmd/rmvolmgr/vold.h
-	$(COMPILE.c) -o $@ $(SRC)/cmd/rmvolmgr/vold.c
-	$(POST_PROCESS_O)
-
-clean:
-	$(RM) $(OBJS)
-
-include ../Makefile.targ
--- old/usr/src/cmd/volrmmount/volrmmount.c	2016-02-16 06:50:35.001082874 -0500
+++ /dev/null	2016-02-16 06:50:35.000000000 -0500
@@ -1,151 +0,0 @@
-/*
- * CDDL HEADER START
- *
- * The contents of this file are subject to the terms of the
- * Common Development and Distribution License (the "License").
- * You may not use this file except in compliance with the License.
- *
- * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
- * or http://www.opensolaris.org/os/licensing.
- * See the License for the specific language governing permissions
- * and limitations under the License.
- *
- * When distributing Covered Code, include this CDDL HEADER in each
- * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
- * If applicable, add the following below this CDDL HEADER, with the
- * fields enclosed by brackets "[]" replaced with your own identifying
- * information: Portions Copyright [yyyy] [name of copyright owner]
- *
- * CDDL HEADER END
- */
-/*
- * Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
- * Use is subject to license terms.
- */
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <string.h>
-#include <strings.h>
-#include <dirent.h>
-#include <signal.h>
-#include <errno.h>
-#include <libintl.h>
-#include <sys/types.h>
-
-#include "vold.h"
-#include "rmm_common.h"
-
-char *progname = "volrmmount";
-
-static void
-usage()
-{
-	(void) fprintf(stderr,
-	    gettext(
-	    "\nusage: %s [-i | -e] [DEVICE | NICKNAME]\n"),
-	    progname);
-	(void) fprintf(stderr,
-	    gettext("or:    %s -d\n"), progname);
-	(void) fprintf(stderr,
-	    gettext(
-	    "options:\t-i        simulate volume being put in/inserted\n"));
-	(void) fprintf(stderr,
-	    gettext(
-	    "options:\t-e        simulate volume being taken out/ejected\n"));
-	(void) fprintf(stderr,
-	    gettext("options:\t-d        show default device\n"));
-	(void) fprintf(stderr,
-	    gettext(
-	    "\nThis command is deprecated. Use rmmount(1) instead.\n"));
-}
-
-int
-main(int argc, char **argv)
-{
-	const char	*opts = "ied";
-	int		c;
-	boolean_t	opt_insert = B_FALSE;
-	boolean_t	opt_eject = B_FALSE;
-	boolean_t	opt_default = B_FALSE;
-	action_t	action;
-	LibHalContext	*hal_ctx;
-	DBusError	error;
-	rmm_error_t	rmm_error;
-	LibHalDrive	*d;
-	GSList		*volumes;
-	const char	*default_name;
-	int		ret = 0;
-
-	while ((c = getopt(argc, argv, opts)) != EOF) {
-		switch (c) {
-		case 'i':
-			opt_insert = B_TRUE;
-			action = REMOUNT;
-			break;
-		case 'e':
-			opt_eject = B_TRUE;
-			action = UNMOUNT;
-			break;
-		case 'd':
-			opt_default = B_TRUE;
-			break;
-		default:
-			usage();
-			return (1);
-		}
-	}
-	if ((opt_insert && opt_eject) ||
-	    (!opt_insert && !opt_eject && !opt_default)) {
-		usage();
-		return (1);
-	}
-
-	if ((hal_ctx = rmm_hal_init(0, 0, 0, 0, &error, &rmm_error)) == NULL) {
-		(void) fprintf(stderr,
-		    gettext("HAL initialization failed: %s\n"),
-		    rmm_strerror(&error, rmm_error));
-		rmm_dbus_error_free(&error);
-		return (1);
-	}
-
-	if (opt_default) {
-		/* -d: print default name and exit */
-		if ((d = rmm_hal_volume_find_default(hal_ctx, &error,
-		    &default_name, &volumes)) == NULL) {
-			default_name = "nothing inserted";
-		} else {
-			rmm_volumes_free(volumes);
-			libhal_drive_free(d);
-		}
-		(void) printf(gettext("Default device is: %s\n"), default_name);
-	} else if (optind == argc) {
-		/* no name provided, use default */
-		if ((d = rmm_hal_volume_find_default(hal_ctx, &error,
-		    &default_name, &volumes)) == NULL) {
-			(void) fprintf(stderr,
-			    gettext("No default media available\n"));
-			ret = 1;
-		} else {
-			rmm_volumes_free(volumes);
-			libhal_drive_free(d);
-			if (!rmm_action(hal_ctx, default_name, action,
-			    0, 0, 0, 0)) {
-				ret = 1;
-			}
-		}
-	} else {
-		for (; optind < argc; optind++) {
-			if (rmm_action(hal_ctx, argv[optind], action,
-			    0, 0, 0, 0) != 0) {
-				ret = 1;
-			}
-		}
-	}
-
-	rmm_hal_fini(hal_ctx);
-
-	return (ret);
-}
--- old/usr/src/man/man1/Makefile	2016-02-16 06:50:35.064684641 -0500
+++ new/usr/src/man/man1/Makefile	2016-02-16 06:50:35.070626815 -0500
@@ -13,6 +13,7 @@
 # Copyright 2011, Richard Lowe
 # Copyright 2015 Nexenta Systems, Inc. All rights reserved.
 # Copyright 2014 Garrett D'Amore <garrett@damore.org>
+# Copyright 2014 Andrew Stormont
 #
 
 include		$(SRC)/Makefile.master
@@ -408,7 +409,6 @@
 		vacation.1			\
 	 	vgrind.1			\
 	 	volcheck.1			\
-	 	volrmmount.1			\
 	 	w.1				\
 	 	wait.1				\
 	 	wc.1				\
--- old/usr/src/man/man1/fdformat.1	2016-02-16 06:50:35.252275940 -0500
+++ new/usr/src/man/man1/fdformat.1	2016-02-16 06:50:35.259131074 -0500
@@ -1,9 +1,10 @@
 '\" te
 .\"  Copyright 2001, Sun Microsystems, Inc All Rights Reserved
+.\"  Copyright 2014 Andrew Stormont.
 .\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
 .\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
 .\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH FDFORMAT 1 "Feb 28, 2007"
+.TH FDFORMAT 1 "May 2, 2014"
 .SH NAME
 fdformat \- format floppy diskette or PCMCIA memory card
 .SH SYNOPSIS
@@ -434,8 +435,8 @@
 .sp
 .LP
 \fBcpio\fR(1), \fBeject\fR(1), \fBrmformat\fR(1), \fBtar\fR(1),
-\fBvolcheck\fR(1), \fBvolrmmount\fR(1), \fBmount\fR(1M), \fBnewfs\fR(1M),
-\fBprtvtoc\fR(1M), \fBattributes\fR(5), \fBpcfs\fR(7FS)
+\fBvolcheck\fR(1), \fBmount\fR(1M), \fBnewfs\fR(1M), \fBprtvtoc\fR(1M),
+\fBattributes\fR(5), \fBpcfs\fR(7FS)
 .SS "x86 Only"
 .sp
 .LP
--- old/usr/src/man/man1/rmformat.1	2016-02-16 06:50:35.544306365 -0500
+++ new/usr/src/man/man1/rmformat.1	2016-02-16 06:50:35.550259638 -0500
@@ -1,9 +1,10 @@
 '\" te
 .\" Copyright (c) 2009, Sun Microsystems, Inc. All Rights Reserved.
+.\" Copyright 2014 Andrew Stormont.
 .\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
 .\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
 .\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH RMFORMAT 1 "Feb 19, 2009"
+.TH RMFORMAT 1 "May 2, 2014"
 .SH NAME
 rmformat \- removable rewritable media format utility
 .SH SYNOPSIS
@@ -511,10 +512,10 @@
 .sp
 .LP
 \fBcpio\fR(1), \fBeject\fR(1), \fBfdformat\fR(1), \fBtar\fR(1),
-\fBvolcheck\fR(1), \fBvolrmmount\fR(1), \fBformat\fR(1M), \fBmkfs_pcfs\fR(1M),
-\fBmount\fR(1M), \fBnewfs\fR(1M), \fBprtvtoc\fR(1M), \fBrmmount\fR(1M),
-\fBrpc.smserverd\fR(1M), \fBattributes\fR(5), \fBscsa2usb\fR(7D), \fBsd\fR(7D),
-\fBpcfs\fR(7FS), \fBudfs\fR(7FS)
+\fBvolcheck\fR(1), \fBformat\fR(1M), \fBmkfs_pcfs\fR(1M), \fBmount\fR(1M),
+\fBnewfs\fR(1M), \fBprtvtoc\fR(1M), \fBrmmount\fR(1M), \fBrpc.smserverd\fR(1M),
+\fBattributes\fR(5), \fBscsa2usb\fR(7D), \fBsd\fR(7D), \fBpcfs\fR(7FS),
+\fBudfs\fR(7FS)
 .sp
 .LP
 \fISystem Administration Guide: Basic Administration\fR
--- old/usr/src/man/man1/volrmmount.1	2016-02-16 06:50:35.839683499 -0500
+++ /dev/null	2016-02-16 06:50:35.000000000 -0500
@@ -1,183 +0,0 @@
-'\" te
-.\"  Copyright (c) 2000, Sun Microsystems, Inc. All Rights Reserved
-.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
-.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
-.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH VOLRMMOUNT 1 "Feb 28, 2007"
-.SH NAME
-volrmmount \- call rmmount to mount or unmount media
-.SH SYNOPSIS
-.LP
-.nf
-\fBvolrmmount\fR [\fB-i\fR | \fB-e\fR] [\fIname\fR | \fInickname\fR]
-.fi
-
-.LP
-.nf
-\fBvolrmmount\fR [\fB-d\fR]
-.fi
-
-.SH DESCRIPTION
-.sp
-.LP
-The \fBvolrmmount\fR utility calls \fBrmmount\fR(1M) to, in effect, simulate an
-insertion (\fB-i\fR) or an ejection (\fB-e\fR). Simulating an insertion often
-means that \fBrmmount\fR will mount the media. Conversely, simulating an
-ejection often means that \fBrmmount\fR will unmount the media. However, these
-actions can vary depending on the \fBrmmount\fR configuration and media type.
-.sp
-.LP
-For example, using default settings, if you insert a music CD, it might not be
-mounted. However, you can configure \fBrmmount\fR so that it calls
-\fBworkman\fR whenever a music CD is inserted.
-.sp
-.LP
-This command allows you to override volume management's usual handling of media
-(see EXAMPLES below).
-.SH OPTIONS
-.sp
-.LP
-The following options are supported:
-.sp
-.ne 2
-.na
-\fB\fB-i\fR\fR
-.ad
-.RS 6n
-Simulates an insertion of the specified media by calling \fBrmmount\fR.
-.RE
-
-.sp
-.ne 2
-.na
-\fB\fB-e\fR\fR
-.ad
-.RS 6n
-Simulates an ejection of the specified media by calling \fBrmmount\fR.
-.RE
-
-.sp
-.ne 2
-.na
-\fB\fB-d\fR\fR
-.ad
-.RS 6n
-Displays the name of the default device for \fBvolrmmount\fR to handle. This
-device is used if no \fIname\fR or \fInickname\fR is supplied.
-.RE
-
-.SH OPERANDS
-.sp
-.LP
-The following operands are supported:
-.sp
-.ne 2
-.na
-\fB\fIname\fR\fR
-.ad
-.RS 12n
-The name that volume management recognizes as the device's name.
-.RE
-
-.sp
-.ne 2
-.na
-\fB\fInickname\fR\fR
-.ad
-.RS 12n
-A shortened version of the device's name. Following is the list of recognized
-nicknames:
-.RE
-
-.sp
-
-.sp
-.TS
-box;
-c | c
-l | l .
-Nickname	Path
-_
-fd	/dev/rdiskette
-_
-fd0	/dev/rdiskette
-_
-fd1	/dev/rdiskette1
-_
-diskette	/dev/rdiskette
-_
-diskette0	/dev/rdiskette0
-_
-diskette1	/dev/rdiskette1
-_
-rdiskette	/dev/rdiskette
-_
-rdiskette0	/dev/rdiskette0
-_
-rdiskette1	/dev/rdiskette1
-_
-floppy	/dev/rdiskette
-_
-floppy0	/dev/rdiskette0
-_
-floppy1	/dev/rdiskette1
-_
-cdrom0	/dev/rdsk/cXtYdZ/\fIlabel\fR
-_
-zip0	/dev/rdsk/cXtYdZ/\fIlabel\fR
-_
-jaz0	/dev/rdsk/cXtYdZ/\fIlabel\fR
-_
-rmdisk0	/dev/rdsk/cXtYdZ/\fIlabel\fR
-.TE
-
-.SH EXAMPLES
-.LP
-\fBExample 1 \fRUsing the volrmmount command
-.sp
-.LP
-When volume management finds a floppy that contains a filesystem, it calls
-\fBrmmount\fR to mount it. If you wish to run \fBtar\fR(1) or \fBcpio\fR(1) on
-that floppy, it must first be unmounted. To unmount the floppy use:
-
-.sp
-.in +2
-.nf
-example% \fBvolrmmount \(mie floppy0\fR
-.fi
-.in -2
-.sp
-
-.sp
-.LP
-After \fBvolrmmount\fR unmounts the floppy, if you wish to re-mount it (rather
-than ejecting it and reinserting it) use:
-
-.sp
-.in +2
-.nf
-example% \fBvolrmmount \(mii floppy0\fR
-.fi
-.in -2
-.sp
-
-.sp
-.LP
-Notice that if you are using a named floppy, you can use its name in place of
-\fBfloppy0\fR.
-
-.SH FILES
-.sp
-.ne 2
-.na
-\fB\fB/dev/volctl\fR\fR
-.ad
-.RS 15n
-volume management control port
-.RE
-
-.SH SEE ALSO
-.sp
-.LP
-\fBcpio\fR(1), \fBeject\fR(1), \fBtar\fR(1), \fBrmmount\fR(1M),
-\fBattributes\fR(5)
--- old/usr/src/man/man1m/rmmount.1m	2016-02-16 06:50:35.901289133 -0500
+++ new/usr/src/man/man1m/rmmount.1m	2016-02-16 06:50:35.907186447 -0500
@@ -1,9 +1,10 @@
 '\" te
 .\"  Copyright (c) 2004, Sun Microsystems, Inc. All Rights Reserved
+.\"  Copyright 2014 Andrew Stormont.
 .\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License").  You may not use this file except in compliance with the License.
 .\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.  See the License for the specific language governing permissions and limitations under the License.
 .\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE.  If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH RMMOUNT 1M "Mar 1, 2007"
+.TH RMMOUNT 1M "May 2, 2014"
 .SH NAME
 rmmount \- removable media mounter for CD-ROM, floppy, Jaz drive, and others
 .SH SYNOPSIS
@@ -18,7 +19,7 @@
 The \fBrmmount\fR utility is a removable media mounter that is executed by
 volume management whenever a removable medium, such as a \fBCD-ROM\fR or a
 floppy, is inserted. Removable media is managed by an application or a volume
-manager. \fBrmmount\fR can also be called by using \fBvolrmmount\fR(1).
+manager.
 .sp
 .LP
 Upon insertion of a medium and following invocation of the \fBvolcheck\fR(1)
@@ -281,7 +282,7 @@
 .SH SEE ALSO
 .sp
 .LP
-\fBvolcheck\fR(1), \fBvolrmmount\fR(1), \fBfsck\fR(1M), \fBdlopen\fR(3C),
+\fBvolcheck\fR(1), \fBfsck\fR(1M), \fBdlopen\fR(3C),
 \fBattributes\fR(5)
 .sp
 .LP
--- old/usr/src/pkg/manifests/service-storage-media-volume-manager.mf	2016-02-16 06:50:36.177216186 -0500
+++ new/usr/src/pkg/manifests/service-storage-media-volume-manager.mf	2016-02-16 06:50:36.183147309 -0500
@@ -22,6 +22,7 @@
 #
 # Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
 # Copyright 2012 Nexenta Systems, Inc. All rights reserved.
+# Copyright 2014 Andrew Stormont.
 #
 
 set name=pkg.fmri value=pkg:/service/storage/media-volume-manager@$(PKGVERS)
@@ -49,12 +50,10 @@
 file path=usr/bin/rmformat mode=4555
 file path=usr/bin/rmmount mode=0555
 file path=usr/bin/volcheck mode=0555
-file path=usr/bin/volrmmount mode=0555
 file path=usr/lib/rmvolmgr mode=0555
 file path=usr/share/man/man1/rmformat.1
 file path=usr/share/man/man1/rmmount.1
 file path=usr/share/man/man1/volcheck.1
-file path=usr/share/man/man1/volrmmount.1
 file path=usr/share/man/man1m/rmmount.1m
 file path=usr/share/man/man1m/rmvolmgr.1m
 legacy pkg=SUNWrmvolmgr desc="Non-graphical removable volume manager" \

--- old/usr/src/cmd/rmformat/rmf_misc.c	2016-02-16 06:50:34.157491601 -0500
+++ new/usr/src/cmd/rmformat/rmf_misc.c	2016-02-16 06:50:34.163458083 -0500
@@ -17,11 +17,12 @@
  * information: Portions Copyright [yyyy] [name of copyright owner]
  *
  * CDDL HEADER END
- */
-
-/*
+ *
+ *
  * Copyright 2009 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
+ *
+ * Copyright 2014 Andrew Stormont.
  */
 
 /*
@@ -87,7 +88,7 @@
  * Function prototypes.
  */
 static int		my_umount(char *mountp);
-static int		my_volrmmount(char *real_name);
+static int		my_rmmount(char *real_name);
 static int		vol_name_to_dev_node(char *vname, char *found);
 static int		vol_lookup(char *supplied, char *found);
 static device_t		*get_device(char *user_supplied, char *node);
@@ -261,7 +262,7 @@
 	 * Do a partial match with the mnttab entries.
 	 * Make sure the match is in the beginning to avoid if
 	 * anybody puts a label similiar to volume manager path names.
 	 * Then use "volrmmount -e <dev_name>" if -U flag is set.
 	 */
 
 	nl = strlen("/vol/dev/");
@@ -316,7 +317,7 @@
 
 	if (ret_val == 1) {
 		if (flag) {
-			if (my_volrmmount(real_name) < 0) {
+			if (my_rmmount(real_name) < 0) {
 				ret_val = -1;
 			}
 		} else {
@@ -1068,7 +1069,7 @@
 }
 
 static int
-my_volrmmount(char *real_name)
+my_rmmount(char *real_name)
 {
 	int pid, rval;
 
@@ -1089,14 +1090,14 @@
 	if (pid == 0) {
 		/* the child */
 		/* get rid of those nasty err messages */
-		DPRINTF1("call_unmount_prog: calling %s \n",
-		    "/usr/bin/volrmmount");
+		DPRINTF1("call_unmount_prog: calling %s\n",
+		    "/usr/bin/rmmount");
 
 		/* Turn on the privileges. */
 		(void) __priv_bracket(PRIV_ON);
-		if (execl("/usr/bin/volrmmount", "/usr/bin/volrmmount", "-e",
+		if (execl("/usr/bin/rmmount", "/usr/bin/rmmount", "-u",
 		    real_name, NULL) < 0) {
-			PERROR("volrmmount exec failed");
+			PERROR("rmmount exec failed");
 			/* Turn off the privileges */
 			(void) __priv_bracket(PRIV_OFF);
 			exit(-1);
@@ -1104,7 +1105,7 @@
 	} else if (waitpid(pid, &rval, 0) == pid) {
 		if (WIFEXITED(rval)) {
 			if (WEXITSTATUS(rval) == 0) {
-				DPRINTF("volrmmount: Success\n");
+				DPRINTF("rmmount: Success\n");
 				return (1);
 			}
 		}
@@ -1160,7 +1161,7 @@
 		total_devices_found++;
 
 		if ((!defer) && !found) {
-			char *sn, *tmpbuf;
+			char *sn, *tmpbuf = NULL;
 			/*
 			 * dev_name is an optional command line input.
 			 */
@@ -261,7 +262,7 @@
 	 * Make sure the match is in the beginning to avoid if
 	 * anybody puts a label similiar to volume manager path names.
-	 * Then use "volrmmount -e <dev_name>" if -U flag is set.
+	 * Then use "rmmount -u <dev_name>" if -U flag is set.
 	 */
 